==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/he-IL/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'משתמש זה יכול להיכנס',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'נכסים שהוקצו ל: שם',
    'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: user_count משתמשים. שים לב שאינך יכול לשנות את תכונות המשתמש שלך באמצעות טופס זה, ועליך לבצע עריכה למשתמש שלך בנפרד.',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר משתמשים בו-זמנית. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'current_assets'    => 'הנכסים נבדקים כעת למשתמש זה',
    'clone'             => 'משתמש משוכפל',
    'contact_user'      => 'שם איש קשר',
    'edit'              => 'ערוך משתמש',
    'filetype_info'     => 'סוגי קבצים מותרים הם png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ו rar.',
    'history_user'      => 'היסטוריה עבור: שם',
    'info'				=> 'מידע',
    'restore_user'		=> 'לחץ כאן כדי לשחזר אותם.',
    'last_login'        => 'כניסה אחרונה',
    'ldap_config_text'  => 'הגדרות תצורה של LDAP נמצאות \'מנהל\'> \'הגדרות\'. המיקום הנבחר (אופציונלי) ייקבע עבור כל המשתמשים המיובאים.',
    'print_assigned'    => 'להדפיס את כל ההקצאות',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'התוכנה נבדקה אל: שם',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'הצג משתמש: שם',
    'usercsv'           => 'קובץ CSV',
    'two_factor_admin_optin_help' => 'הגדרות מנהל המערכת הנוכחיות מאפשרות אכיפה סלקטיבית של אימות דו-גורמי.',
    'two_factor_enrolled' => 'רשם מכשיר 2FA',
    'two_factor_active'   => '2FA פעיל',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/he-IL/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'משתמש זה יכול להיכנס',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'נכסים שהוקצו ל: שם',
    'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: user_count משתמשים. שים לב שאינך יכול לשנות את תכונות המשתמש שלך באמצעות טופס זה, ועליך לבצע עריכה למשתמש שלך בנפרד.',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר משתמשים בו-זמנית. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'current_assets'    => 'הנכסים נבדקים כעת למשתמש זה',
    'clone'             => 'משתמש משוכפל',
    'contact_user'      => 'שם איש קשר',
    'edit'              => 'ערוך משתמש',
    'filetype_info'     => 'סוגי קבצים מותרים הם png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ו rar.',
    'history_user'      => 'היסטוריה עבור: שם',
    'info'				=> 'מידע',
    'restore_user'		=> 'לחץ כאן כדי לשחזר אותם.',
    'last_login'        => 'כניסה אחרונה',
    'ldap_config_text'  => 'הגדרות תצורה של LDAP נמצאות \'מנהל\'> \'הגדרות\'. המיקום הנבחר (אופציונלי) ייקבע עבור כל המשתמשים המיובאים.',
    'print_assigned'    => 'להדפיס את כל ההקצאות',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'התוכנה נבדקה אל: שם',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'הצג משתמש: שם',
    'usercsv'           => 'קובץ CSV',
    'two_factor_admin_optin_help' => 'הגדרות מנהל המערכת הנוכחיות מאפשרות אכיפה סלקטיבית של אימות דו-גורמי.',
    'two_factor_enrolled' => 'רשם מכשיר 2FA',
    'two_factor_active'   => '2FA פעיל',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
